==> zio-aws-serverlessapplicationrepository_3-5.17.104.7-sources.jar: zio/aws/serverlessapplicationrepository/model/package.scala <==
package zio.aws.serverlessapplicationrepository
import zio.prelude.Subtype
import zio.aws.serverlessapplicationrepository.model.primitives.MaxItems.Type
import zio.aws.serverlessapplicationrepository.model.primitives.__string
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxItems extends Subtype[Int]
    type MaxItems =
      zio.aws.serverlessapplicationrepository.model.primitives.MaxItems.Type
    object __boolean extends Subtype[Boolean]
    type __boolean =
      zio.aws.serverlessapplicationrepository.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer =
      zio.aws.serverlessapplicationrepository.model.primitives.__integer.Type
    object __string extends Subtype[String]
    type __string =
      zio.aws.serverlessapplicationrepository.model.primitives.__string.Type
  }
  type __listOfApplicationDependencySummary = List[
    zio.aws.serverlessapplicationrepository.model.ApplicationDependencySummary
  ]
  type __listOfApplicationPolicyStatement = List[
    zio.aws.serverlessapplicationrepository.model.ApplicationPolicyStatement
  ]
  type __listOfApplicationSummary =
    List[zio.aws.serverlessapplicationrepository.model.ApplicationSummary]
  type __listOfCapability =
    List[zio.aws.serverlessapplicationrepository.model.Capability]
  type __listOfParameterDefinition =
    List[zio.aws.serverlessapplicationrepository.model.ParameterDefinition]
  type __listOfParameterValue =
    List[zio.aws.serverlessapplicationrepository.model.ParameterValue]
  type __listOfRollbackTrigger =
    List[zio.aws.serverlessapplicationrepository.model.RollbackTrigger]
  type __listOfTag = List[zio.aws.serverlessapplicationrepository.model.Tag]
  type __listOfVersionSummary =
    List[zio.aws.serverlessapplicationrepository.model.VersionSummary]
  type __listOf__string = List[__string]
}

==> zio-aws-serverlessapplicationrepository_3-5.17.295.2-sources.jar: zio/aws/serverlessapplicationrepository/model/package.scala <==
package zio.aws.serverlessapplicationrepository
import zio.prelude.Subtype
import zio.aws.serverlessapplicationrepository.model.primitives.MaxItems.Type
import zio.aws.serverlessapplicationrepository.model.primitives.__string
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxItems extends Subtype[Int]
    type MaxItems =
      zio.aws.serverlessapplicationrepository.model.primitives.MaxItems.Type
    type __boolean = Boolean
    type __integer = Int
    type __string = String
  }
  type __listOfApplicationDependencySummary = List[
    zio.aws.serverlessapplicationrepository.model.ApplicationDependencySummary
  ]
  type __listOfApplicationPolicyStatement = List[
    zio.aws.serverlessapplicationrepository.model.ApplicationPolicyStatement
  ]
  type __listOfApplicationSummary =
    List[zio.aws.serverlessapplicationrepository.model.ApplicationSummary]
  type __listOfCapability =
    List[zio.aws.serverlessapplicationrepository.model.Capability]
  type __listOfParameterDefinition =
    List[zio.aws.serverlessapplicationrepository.model.ParameterDefinition]
  type __listOfParameterValue =
    List[zio.aws.serverlessapplicationrepository.model.ParameterValue]
  type __listOfRollbackTrigger =
    List[zio.aws.serverlessapplicationrepository.model.RollbackTrigger]
  type __listOfTag = List[zio.aws.serverlessapplicationrepository.model.Tag]
  type __listOfVersionSummary =
    List[zio.aws.serverlessapplicationrepository.model.VersionSummary]
  type __listOf__string = List[__string]
}
